"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.LlamaContext = void 0;
exports.initLlama = initLlama;
exports.releaseAllLlama = releaseAllLlama;
exports.setContextLimit = setContextLimit;
var _reactNative = require("react-native");
var _NativeRNLlama = _interopRequireDefault(require("./NativeRNLlama"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const EVENT_ON_TOKEN = '@RNLlama_onToken';
const EventEmitter =
// @ts-ignore
new _reactNative.NativeEventEmitter(_NativeRNLlama.default);
class LlamaContext {
  constructor(id) {
    this.id = id;
  }
  async completion(params, callback) {
    let tokenListener = EventEmitter.addListener(EVENT_ON_TOKEN, evt => {
      const {
        contextId,
        tokenResult
      } = evt;
      if (contextId !== this.id) return;
      callback(tokenResult);
    });
    const promise = _NativeRNLlama.default.completion(this.id, params);
    return promise.then(completionResult => {
      tokenListener.remove();
      tokenListener = null;
      return completionResult;
    }).catch(err => {
      tokenListener.remove();
      tokenListener = null;
      throw err;
    });
  }
  stopCompletion() {
    return _NativeRNLlama.default.stopCompletion(this.id);
  }
  async release() {
    return _NativeRNLlama.default.releaseContext(this.id);
  }
}
exports.LlamaContext = LlamaContext;
async function setContextLimit(limit) {
  return _NativeRNLlama.default.setContextLimit(limit);
}
async function initLlama(_ref) {
  let {
    model,
    is_model_asset: isModelAsset,
    ...rest
  } = _ref;
  let path = model;
  if (path.startsWith('file://')) path = path.slice(7);
  const id = await _NativeRNLlama.default.initContext({
    model: path,
    is_model_asset: !!isModelAsset,
    ...rest
  });
  return new LlamaContext(id);
}
async function releaseAllLlama() {
  return _NativeRNLlama.default.releaseAllContexts();
}
//# sourceMappingURL=index.js.map