import { NativeEventEmitter } from 'react-native';
import RNLlama from './NativeRNLlama';
const EVENT_ON_TOKEN = '@RNLlama_onToken';
const EventEmitter =
// @ts-ignore
new NativeEventEmitter(RNLlama);
export class LlamaContext {
  constructor(id) {
    this.id = id;
  }
  async completion(params, callback) {
    let tokenListener = EventEmitter.addListener(EVENT_ON_TOKEN, evt => {
      const {
        contextId,
        tokenResult
      } = evt;
      if (contextId !== this.id) return;
      callback(tokenResult);
    });
    const promise = RNLlama.completion(this.id, params);
    return promise.then(completionResult => {
      tokenListener.remove();
      tokenListener = null;
      return completionResult;
    }).catch(err => {
      tokenListener.remove();
      tokenListener = null;
      throw err;
    });
  }
  stopCompletion() {
    return RNLlama.stopCompletion(this.id);
  }
  async release() {
    return RNLlama.releaseContext(this.id);
  }
}
export async function setContextLimit(limit) {
  return RNLlama.setContextLimit(limit);
}
export async function initLlama(_ref) {
  let {
    model,
    is_model_asset: isModelAsset,
    ...rest
  } = _ref;
  let path = model;
  if (path.startsWith('file://')) path = path.slice(7);
  const id = await RNLlama.initContext({
    model: path,
    is_model_asset: !!isModelAsset,
    ...rest
  });
  return new LlamaContext(id);
}
export async function releaseAllLlama() {
  return RNLlama.releaseAllContexts();
}
//# sourceMappingURL=index.js.map